@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Provide musical cadence chords
 
-our $VERSION = '0.0103';
+our $VERSION = '0.0104';
 
 use Music::Chord::Note;
 use Music::Scales;
@@ -87,7 +87,7 @@ Music::Cadence - Provide musical cadence chords
 
 =head1 VERSION
 
-version 0.0103
+version 0.0104
 
 =head1 SYNOPSIS
 
@@ -114,6 +114,9 @@ version 0.0103
 
 C<Music::Cadence> provides musical cadence chords.
 
+* This module is a very naive implementation of the actual theory.
+YMMV.
+
 =head1 ATTRIBUTES
 
 None.
@@ -128,7 +131,7 @@ Create a new C<Music::Cadence> object.
 
 =head2 cadence
 
-  $notes = $mc->cadence;        # Use defaults
+  $notes = $mc->cadence;  # Use defaults
 
   $notes = $mc->cadence(
     key     => $key,      # Default: C
